@@ -21,6 +21,7 @@
 #include <kmenu.h>
 #include <ktoolinvocation.h>
 #include <klocalizedstring.h>
+#include <kdebug.h>
 
 #include <QtGui/QAction>
 #include <QtGui/QMenu>
@@ -66,17 +67,23 @@ void LayoutsMenu::actionTriggered(QAction* action)
 
 int LayoutsMenu::switchToLayout(const LayoutUnit& layoutUnit, const KeyboardConfig& keyboardConfig)
 {
+	QList<LayoutUnit> layouts = X11Helper::getCurrentLayouts().layouts;
+
 	bool res;
-	if( X11Helper::getCurrentLayouts().layouts.contains(layoutUnit) ) {
+	if( layouts.contains(layoutUnit) ) {
 		res = X11Helper::setLayout(layoutUnit);
 	}
-	else {
+	else if ( keyboardConfig.isSpareLayoutsEnabled() && keyboardConfig.layouts.contains(layoutUnit) ) {
 		QList<LayoutUnit> layouts(keyboardConfig.getDefaultLayouts());
 		layouts.removeLast();
 		layouts.append(layoutUnit);
 		XkbHelper::initializeKeyboardLayouts(layouts);
 		res = X11Helper::setLayout(layoutUnit);
 	}
+	else {
+		kWarning() << "switchToLayout with unknown layout" << layoutUnit.toString();
+		res = -1;
+	}
 	return res;
 }
 
