@@ -572,6 +572,8 @@ private:
     Time readUserCreationTime() const;
     void startupIdChanged();
 
+    void checkOffscreenPosition (QRect& geom, const QRect& screenArea);
+
     Window client;
     Window wrapper;
     KDecoration* decoration;
@@ -644,6 +646,7 @@ private:
     uint urgency : 1; ///< XWMHints, UrgencyHint
     uint ignore_focus_stealing : 1; ///< Don't apply focus stealing prevention to this client
     uint demands_attention : 1;
+    int m_screenNum, m_formerScreenNum;
     bool blocks_compositing;
     WindowRules client_rules;
     void getWMHints();
