@@ -51,6 +51,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QLabel>
 #include <KComboBox>
 #include <QVBoxLayout>
+#include <kworkspace.h>
 
 #include <ksmserver_interface.h>
 
@@ -404,6 +405,8 @@ KDE_EXPORT int kdemain(int argc, char * argv[])
         }
     }
 
+    KWorkSpace::trimMalloc();
+
     Display* dpy = XOpenDisplay(NULL);
     if (!dpy) {
         fprintf(stderr, "%s: FATAL ERROR while trying to open display %s\n",
