@@ -194,6 +194,9 @@ namespace Oxygen
     void Helper::renderBackgroundPixmap( QPainter* p, const QRect& clipRect, const QWidget* widget, const QWidget* window, int yShift, int gradientHeight )
     {
 
+        // background pixmap
+        if( _backgroundPixmap.isNull() ) return;
+
         // get coordinates relative to the client area
         // this is stupid. One could use mapTo if this was taking const QWidget* and not
         // QWidget* as argument.
@@ -224,22 +227,16 @@ namespace Oxygen
         // account for vertical shift
         if( yShift > 0 ) height -= 2*yShift;
 
-        // background pixmap
-        if( !_backgroundPixmap.isNull() )
-        {
+        // calculate source rect
+        QPoint offset( 40, 48 - 20 );
+        QRect source( 0, 0, width + offset.x(), height + offset.y() );
 
-            // calculate source rect
-            QPoint offset( 40, 48 - 20 );
-            QRect source( 0, 0, width + offset.x(), height + offset.y() );
+        offset -= _backgroundPixmapOffset;
+        source.translate( offset.x(), offset.y() );
+        source.translate( 0, 64 - gradientHeight );
 
-            offset -= _backgroundPixmapOffset;
-            source.translate( offset.x(), offset.y() );
-            source.translate( 0, 64 - gradientHeight );
-
-            // draw
-            p->drawPixmap( QPoint( -x, -y ), _backgroundPixmap, source );
-
-        }
+        // draw
+        p->drawPixmap( QPoint( -x, -y ), _backgroundPixmap, source );
 
         if ( clipRect.isValid() )
         { p->restore(); }
@@ -434,6 +431,11 @@ namespace Oxygen
                 KColorUtils::mix( Qt::black, color, color.alphaF() ),
                 KColorScheme::ShadowShade,
                 _contrast ) );
+
+            // make sure shadow color has the same alpha channel as the input
+            out->setAlpha( color.alpha() );
+
+            // insert in cache
             _shadowColorCache.insert( key, out );
         }
 
