@@ -472,7 +472,7 @@ void Image::addUrl(const KUrl &url, bool setAsCurrent)
         if (setAsCurrent) {
             setWallpaper(path);
         } else {
-            if (m_wallpaper.isEmpty()) {
+            if (m_mode != "SingleImage") {
                 // it's a slide show, add it to the slide show
                 m_slideshowBackgrounds.append(path);
             }
@@ -514,14 +514,14 @@ void Image::addWallpaperRetrieved(KJob *job)
 
 void Image::setWallpaper(const QString &path)
 {
-    if (m_wallpaper.isEmpty()) {
+    if (m_mode == "SingleImage") {
+        m_wallpaper = path;
+        setSingleImage();
+    } else {
         m_slideshowBackgrounds.append(path);
         m_currentSlide = m_slideshowBackgrounds.size() - 2;
         nextSlide();
         updateWallpaperActions();
-    } else {
-        m_wallpaper = path;
-        setSingleImage();
     }
 
     if (!m_usersWallpapers.contains(path)) {
